FlutterUnionadEcpm class

@Author: gstory @CreateDate: 2025/3/12 15:43 @Email gstory0404@gmail.com @Description: dart类作用描述

Constructors

FlutterUnionadEcpm({String? adnName, String? customAdnName, String? slotID, String? levelTag, String? ecpm, int? biddingType, String? errorMsg, String? requestID, String? creativeID, String? adRitType, String? segmentId, String? abtestId, String? channel, String? subChannel, String? scenarioId, String? subRitType})
FlutterUnionadEcpm.fromJson(Map<String, dynamic> json)

Properties

abtestId ↔ String?
getter/setter pair
adnName ↔ String?
getter/setter pair
adRitType ↔ String?
getter/setter pair
biddingType ↔ int?
getter/setter pair
channel ↔ String?
getter/setter pair
creativeID ↔ String?
getter/setter pair
customAdnName ↔ String?
getter/setter pair
ecpm ↔ String?
getter/setter pair
errorMsg ↔ String?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
levelTag ↔ String?
getter/setter pair
requestID ↔ String?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
scenarioId ↔ String?
getter/setter pair
segmentId ↔ String?
getter/setter pair
slotID ↔ String?
getter/setter pair
subChannel ↔ String?
getter/setter pair
subRitType ↔ String?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited