FlutterUnionadStream class

@Author: gstory @CreateDate: 2021/5/25 7:45 下午 @Description: 广告结果监听

Constructors

FlutterUnionadStream()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

deleteAdStream(StreamSubscription stream) → void
initAdStream({FlutterUnionadFullVideoCallBack? flutterUnionadFullVideoCallBack, FlutterUnionadInteractionCallBack? flutterUnionadInteractionCallBack, FlutterUnionadNewInteractionCallBack? flutterUnionadNewInteractionCallBack, FlutterUnionadRewardAdCallBack? flutterUnionadRewardAdCallBack}) → StreamSubscription
注册stream监听原生返回的信息